@@ -241,3 +241,14 @@ class WBGenericDBManager(AbstractWBDBManager):
         with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
             curs.execute("SELECT cur_paper FROM cur_strdata where cur_datatype = 'antibody'")
             return [row[0] for row in curs.fetchall()]
+
+    def get_antibody_str_values(self, from_date):
+        with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
+            curs.execute("SELECT cur_paper, cur_strdata FROM cur_strdata where cur_datatype = 'antibody' "
+                         "and cur_timestamp >= %(from_date)s", {'from_date': from_date})
+            return [(row[0], row[1]) for row in curs.fetchall()]
+
+    def save_antybody_str_values(self, paper_id, str_values):
+        with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
+            curs.execute("INSERT INTO cur_strdata (cur_paper, cur_datatype, cur_strdata) "
+                         "VALUES (%s, 'antibody', %s)", (paper_id, str_values))
